import { Card, CardBody, CardTitle, Grid, GridItem } from "@patternfly/react-core";
import React from "react";
import cockpit from "cockpit";
import { NodeRedLink } from "./NodeRedLinkButton.jsx";
import { RevPiHelpText } from "../common.components.jsx";
import { InstallFeatureCard } from "./InstallFeature.jsx";

const _ = cockpit.gettext;

export function NodeRedCard ({ getRevPiSwitch, item }) {
    const cardTitle = _("Node-RED");
    const nodeRedPackageName = ["revpi-nodered", "revpi-nodered-proxy-apache", "noderedrevpinodes-server"];
    const nodeRedFeatureName = "Node-RED";
    const { isEnabled } = item;

    return (
        <Card isFullHeight name='node-red'>
            <CardTitle>
                {cardTitle}
                <RevPiHelpText title={cardTitle}>
                    {_("A simple flow-based tool for connecting devices and automating workflows.")}
                </RevPiHelpText>
            </CardTitle>
            <CardBody>
                <Grid hasGutter>
                    <GridItem span={12}>
                        <InstallFeatureCard packagesName={nodeRedPackageName} featureName={nodeRedFeatureName}>
                            <NodeRedLink isEnabled={isEnabled} />
                        </InstallFeatureCard>
                    </GridItem>
                    <GridItem span={12}>
                        {getRevPiSwitch("nodered")}
                    </GridItem>
                    <GridItem span={12}>
                        {getRevPiSwitch("noderedrevpinodes-server")}
                    </GridItem>
                </Grid>
            </CardBody>
        </Card>
    );
}
