import React, { useState, useCallback } from "react";
import cockpit from "cockpit";
import { Alert, Button } from "@patternfly/react-core";
import { OutlinedWindowRestoreIcon } from "@patternfly/react-icons";
import { getHostName } from "../revpi-config/RevPiConfigService.jsx";

const _ = cockpit.gettext;

const scriptLocations = [
    "/usr/local/share/cockpit/revpi-config/scripts/create_sso_token.sh",
    "/usr/share/cockpit/revpi-config/scripts/create_sso_token.sh"
];

// Function to create an SSO token by checking multiple script locations
const createSsoToken = async () => {
    for (const location of scriptLocations) {
        try {
            return await cockpit.spawn(location, { superuser: "require" });
        } catch (error) {
            console.log(`No script found at '${location}'. Trying next location...`, error);
        }
    }
    throw new Error("No script found at any given location.");
};

// Functional component version of PictoryLink
export function PictoryLink () {
    const [isLoading, setIsLoading] = useState(false);
    const [hasError, setHasError] = useState(false);

    // Handle button click with proper error handling
    const handlePiCtoryButtonClick = useCallback(async () => {
        setIsLoading(true);
        setHasError(false);

        try {
            const token = await createSsoToken();
            const url = `https://${getHostName()}:41443/pictory/php/sso_login.php?sso_token=${token}`;
            window.open(url, "_blank");
        } catch (error) {
            setHasError(true);
            console.error("Error while creating SSO token", error);
        } finally {
            setIsLoading(false);
        }
    }, []);

    return (
        <>
            {hasError && (
                <Alert
                    variant='danger'
                    isInline
                    title={_("An issue occurred while generating your login token for PiCtory.")}
                />
            )}
            <Button
                isBlock
                variant='primary'
                size='lg'
                icon={<OutlinedWindowRestoreIcon />}
                isLoading={isLoading}
                onClick={handlePiCtoryButtonClick}
            >
                PiCtory
            </Button>
        </>
    );
}
